@@ -30,11 +30,11 @@ def validate_resume(
 
     if validator.validate(yaml_resume):  # type: ignore
         info_message = (
-            "Resume in location {context_location} validates to the resume_schema"
+            f"Resume in location {yaml_resume} validates to the resume_schema"
         )
         validation_flag = True
         return info_message, validation_flag
     else:
-        warning_message = f"The resume in location {context_location} does not validate to the resume_schema\n\tErrors: {validation_error}".format(validation_error=validator.errors)  # type: ignore
+        warning_message = f"The resume in location {yaml_resume} does not validate to the resume_schema\n\tErrors: {validation_error}".format(validation_error=validator.errors)  # type: ignore
         validation_flag = False
         return warning_message, validation_flag
